# Feishu Bot
## Install
```
pip install feishu_bot
```
## Getting Started
```
from feishu_bot import FeishuBot

bot = FeishuBot('your_app_id', 'your_app_secret')
await bot.send_text('test')
```
## Features
- Automatically token management
- Cache embeded